/*
 * DozierRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp program.
 * Copyright (C) 1998 J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Last revision: 01-Apr-1998
 *
 */


#include "gvdozier.h"



void const DozierRandomCspC::ProduceProblem ()
{
	unsigned long int c, t;
	unsigned int i, j, x, y = 0;

	Reset ();

	for (i = 0; i <= GetNumberOfVariables () - 1; i++)
		if (IsRandomDomainSize ())
			SetDomainSize (i, (RandomGenerator.asLong () % GetGlobalDomainSize ()) + 1);
		else
			SetDomainSize (i, GetGlobalDomainSize ());

	/* double -> unsigned int = ugly code! */
	c = (unsigned long int) (GetConnectivity () * GetNumberOfVariables () * (GetNumberOfVariables () - 1) * 0.5);

	while (c > 0)
	{
		do
		{
			i = RandomGenerator.asLong () % GetNumberOfVariables ();
			j = RandomGenerator.asLong () % GetNumberOfVariables ();
		}
		while (i == j);


		if (!IsConstraint (i, j))
		{
			AddConstraint (i, j);

			/* double -> unsigned int = ugly code! */
			t = (unsigned long int) (GetTightness () * GetDomainSize (i) * GetDomainSize (j));

			while (t > 0)
			{
				x = RandomGenerator.asLong () % GetDomainSize (i);
				y = RandomGenerator.asLong () % GetDomainSize (j);

				if (!IsConflict (i, j, x, y))
				{
					AddConflict (i, j, x, y);

					t--;
				}
			}

			c--;
		}
	}

} // DozierRandomCspC::ProduceProblem



// eof dozier.cc
